@@ -55,3 +55,23 @@ def test_gha_download_all():
     ghalatest = GitHubSource()
     data = ghalatest.download_all()
     assert len(data) > 1000
+
+
+def test_gha_version_ranges():
+    source = GitHubSource()
+    version_list = source.get_version_range("< 1.10.2")
+    assert version_list == ("", "", "", "1.10.2")
+    version_list = source.get_version_range("= 0.2.0")
+    assert version_list == ("", "0.2.0", "", "")
+    version_list = source.get_version_range("<= 1.0.8")
+    assert version_list == ("", "1.0.8", "", "")
+    version_list = source.get_version_range(">= 4.3.0, < 4.3.5")
+    assert version_list == ("4.3.0", "", "", "4.3.5")
+    version_list = source.get_version_range(">= 0.5.1")
+    assert version_list == ("0.5.1", "", "", "")
+    version_list = source.get_version_range("> 2.2.0, < 3.1.8")
+    assert version_list == ("", "", "2.2.0", "3.1.8")
+    version_list = source.get_version_range("> 2.0.0, <= 2.0.14")
+    assert version_list == ("", "2.0.14", "2.0.0", "")
+    version_list = source.get_version_range(">= 1.0.0, <= 2.0.14")
+    assert version_list == ("1.0.0", "2.0.14", "", "")
