@@ -10,6 +10,8 @@ def test_normalise():
 
     res = utils.normalise_num(100, 2)
     assert res == 100
+    assert utils.normalise_version_str("2.0.0", 3) == "2.0.0"
+    assert utils.normalise_version_str("2.0.10", 4) == "2.0.10.0"
 
 
 def test_version_compare():
@@ -40,6 +42,14 @@ def test_version_parts_compare():
     assert not res
     res = utils.version_compare("1.2.0", "0.7.0", "1.2.0")
     assert res
+    res = utils.version_compare("2.1.8", "2.0.0", "2.0.14")
+    assert not res
+    res = utils.version_compare("2.1.800.0", "2.0.0", "2.2.14")
+    assert res
+    res = utils.version_compare("2.1.8.0", "2.0.0.800", "2.2.14.10")
+    assert res
+    res = utils.version_compare("82.1.8.0", "52.0.0", "96.2")
+    assert res
 
 
 def test_version_build_compare():
@@ -62,3 +72,19 @@ def test_parse_uri():
     assert vendor == "google"
     assert package == "android"
     assert version == "9.0"
+
+
+def test_version_len():
+    assert utils.version_len("1.0.0") == 3
+    assert utils.version_len("2.1.800.5") == 6
+    assert utils.version_len("1.2.0-beta1") == 3
+    assert utils.version_len("1.3.0.beta1") == 3
+
+
+def test_fix_test():
+    assert (
+        utils.fix_text(
+            "Unauthenticated crypto and weak IV in Magento\Framework\Encryption"
+        )
+        == "Unauthenticated crypto and weak IV in Magento Framework Encryption"
+    )
