@@ -1,4 +1,5 @@
 import importlib
+import re
 from datetime import datetime
 from enum import Enum
 
@@ -132,6 +133,31 @@ def serialize_vuln_list(datas):
     return data_list
 
 
+def version_len(version_str):
+    """
+    Method to return the length of a version string without dots and build
+    information
+
+    >>> version_len("1.0.0")
+    3
+
+    >>> version_len("2.1.800.5")
+    6
+
+    >>> version_len("1.2.0-beta1")
+    3
+
+    >>> version_len("1.3.0.beta1")
+    3
+
+    :param version_str: Version string
+    :return: Length of the string without dots and build information
+    """
+    version_str = version_str.split("-")
+    version_parts = [v for v in version_str[0].split(".") if str(v).isdigit()]
+    return len("".join(version_parts))
+
+
 def convert_to_num(version_str):
     """Convert the version string to a number
 
@@ -242,13 +268,21 @@ def version_compare(compare_ver, min_version, max_version):
     min_version_parts = str(min_version).split(".")
     max_version_parts = str(max_version).split(".")
 
+    normal_ver_len = version_len(compare_ver)
+    if version_len(min_version) > normal_ver_len:
+        normal_ver_len = version_len(min_version)
+    if version_len(max_version) > normal_ver_len:
+        normal_ver_len = version_len(max_version)
+    compare_ver_num = normalise_num(compare_ver, normal_ver_len)
+    min_version_num = normalise_num(min_version, normal_ver_len)
+    max_version_num = normalise_num(max_version, normal_ver_len)
     # If all versions follow proper versioning then perform a simple numerical comparison
-    if len(compare_ver_parts) == len(min_version_parts) and len(
-        compare_ver_parts
-    ) == len(max_version_parts):
-        compare_ver_num = normalise_num(compare_ver, len(compare_ver_parts))
-        min_version_num = normalise_num(min_version, len(compare_ver_parts))
-        max_version_num = normalise_num(max_version, len(compare_ver_parts))
+    if (
+        len(compare_ver_parts) == len(min_version_parts)
+        and len(compare_ver_parts) == len(max_version_parts)
+        and len(str(compare_ver_num)) == len(str(min_version_num))
+        and len(str(compare_ver_num)) == len(str(max_version_num))
+    ):
         if compare_ver_num >= min_version_num and compare_ver_num <= max_version_num:
             if (
                 compare_ver_build == min_version_build
@@ -299,8 +333,20 @@ def version_compare(compare_ver, min_version, max_version):
             compare_ver_parts[i]
         ) <= int(max_version_parts[i]):
             continue
-        else:
-            return False
+        elif int(compare_ver_parts[i]) < int(min_version_parts[i]) or int(
+            compare_ver_parts[i]
+        ) > int(max_version_parts[i]):
+            if i == 0:
+                return False
+            if i == 1 and int(compare_ver_parts[i - 1]) <= int(
+                max_version_parts[i - 1]
+            ):
+                return False
+            if i >= 2 and int(compare_ver_parts[i - 1]) == int(
+                max_version_parts[i - 1]
+            ):
+                return False
+
     return True
 
 
@@ -381,3 +427,15 @@ def convert_to_occurrence(datas):
             id_list.append(unique_key)
             data_list.append(occ)
     return data_list
+
+
+def fix_text(text):
+    """
+    Method to fix up bad text from feeds
+    :param text: Text to cleanup
+    :return: Fixed text
+    """
+    if text is None:
+        text = ""
+    text = re.sub(r"[]^\\-]", " ", text)
+    return text
